==> mp3plot-0.5.1.tar.gz: mp3plot-0.5.1/src/plotters/image_plotter.cc <==
/*
 * mp3plot - Bitrate analysis tool
 *
 * Copyright (C) 2007, 2009 Toni Corvera
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

// $Id: image_plotter.cc 1702 2009-04-24 20:18:17Z  $

#include "image_plotter.h"

#ifndef DISABLE_GRAPHICS

#include <iostream>
#include "../mp3/bitrate.h"

#include "old_colourscheme.inc.cc"
#include "colourscheme.inc.cc"

namespace mp3plot {

const unsigned int image_plotter::IMGW = 1024,
                   image_plotter::IMGH = 768;

rgb_type image_plotter::bitrate_colour(bitrate_t br, bool old) {
    const std::map<bitrate_t, rgb_type> * pm = 0;
    if (!old) {
        pm =& mp3plot::impl::colourscheme::get_map();
    }
    else {
        pm =& mp3plot::impl::old_colourscheme::get_map();
    }
    assert( pm->find(br) != pm->end() );
    return pm->find(br)->second;
}

} // namespace mp3plot

#endif // DISABLE_GRAPHICS

// vim:set ts=4 et ai: //

==> mp3plot-0.6.0.tar.gz: mp3plot-0.6.0/src/plotters/image_plotter.cc <==
/*
 * mp3plot - Bitrate analysis tool
 *
 * Copyright (C) 2007, 2009 Toni Corvera
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

// $Id: image_plotter.cc 1344 2009-06-22 01:11:09Z toni $

#include "image_plotter.h"

#ifndef DISABLE_GRAPHICS

#include <iostream>
#include "../mp3/bitrate.h"

// Colourschemes, they define the colours used in the graphical histogram
//  and "colourband"
#include "old_colourscheme.inc.cc"
#include "colourscheme.inc.cc"

namespace mp3plot {

const unsigned int image_plotter::IMGW = 1024,
                   image_plotter::IMGH = 768;

rgb_type image_plotter::bitrate_colour(uint8_t bridx, bool old) {
    const std::map<uint8_t, rgb_type> * pm = 0;
    if (!old) {
        pm =& mp3plot::impl::colourscheme::get_map();
    }
    else {
        pm =& mp3plot::impl::old_colourscheme::get_map();
    }
    assert( pm->find(bridx) != pm->end() );
    return pm->find(bridx)->second;
}

} // namespace mp3plot

#endif // DISABLE_GRAPHICS

// vim:set ts=4 et ai: //
